CameraController

Struct CameraController 

pub struct CameraController {
    pub active_button: Option<MouseButton>,
    pub last_mouse_pos: Vec2,
    pub mouse_delta: Vec2,
}
Camera controller for handling input events

Fields

active_button: Option<MouseButton>last_mouse_pos: Vec2mouse_delta: Vec2

Implementations

Source

impl CameraController

pub fn new() -> Self

pub fn mouse_press( &mut self, position: Vec2, button: MouseButton, _modifiers: Modifiers, )

Handle mouse press

pub fn mouse_release( &mut self, _position: Vec2, button: MouseButton, _modifiers: Modifiers, )

Handle mouse release

pub fn mouse_move( &mut self, position: Vec2, delta: Vec2, viewport_px: (u32, u32), modifiers: Modifiers, camera: &mut Camera, )

Handle mouse movement

For 3D (perspective) cameras:

  • left drag: orbit/rotate
  • right drag: pan

For 2D (orthographic) cameras, we treat drag as pan by shifting the orthographic bounds in data-space. We avoid translating the view matrix in X/Y because the ortho bounds already live in data coordinates.

pub fn mouse_wheel( &mut self, delta: Vec2, position_px: Vec2, viewport_px: (u32, u32), modifiers: Modifiers, camera: &mut Camera, )

Handle mouse wheel