pub struct GpuPackContext<'a> {
pub device: &'a Arc<Device>,
pub queue: &'a Arc<Queue>,
}Expand description
GPU context used by plot elements to build viewport-aware GPU geometry.
On wasm, some geometry generation is deferred until render-time so we can incorporate the
current viewport pixel size (e.g. to convert LineWidth pixels → data units).
Fields
device: &'a Arc<Device>queue: &'a Arc<Queue>Auto Trait Implementations
impl<'a> Freeze for GpuPackContext<'a>
impl<'a> !RefUnwindSafe for GpuPackContext<'a>
impl<'a> Send for GpuPackContext<'a>
impl<'a> Sync for GpuPackContext<'a>
impl<'a> Unpin for GpuPackContext<'a>
impl<'a> UnsafeUnpin for GpuPackContext<'a>
impl<'a> !UnwindSafe for GpuPackContext<'a>