pub struct RenderResult {
pub success: bool,
pub data_bounds: Option<(f64, f64, f64, f64)>,
pub axes_viewports_px: Vec<(u32, u32, u32, u32)>,
pub vertex_count: usize,
pub triangle_count: usize,
pub render_time_ms: f64,
}Expand description
Result of rendering operation
Fields
success: boolWhether rendering was successful
data_bounds: Option<(f64, f64, f64, f64)>Rendered data bounds
axes_viewports_px: Vec<(u32, u32, u32, u32)>Axes viewports in physical pixels as (x, y, width, height).
Hosts use these rectangles to route pointer events and picking through the same viewport that was used for rendering.
vertex_count: usizePerformance metrics
triangle_count: usizerender_time_ms: f64Trait Implementations