Module scene

Module scene 

Scene graph system for organizing and managing plot objects

Provides hierarchical organization of plot elements with efficient culling, level-of-detail, and batch rendering capabilities.

Structs

BoundingBox
Axis-aligned bounding box
DrawCall
Draw call for efficient batching
DrawIndirectArgsRaw
POD layout matching wgpu’s non-indexed indirect draw arguments.
Frustum
View frustum for culling
GpuIndirectDraw
GPU-driven draw call arguments for draw_indirect.
GpuVertexBuffer
Optional GPU-resident vertex storage supplied by higher-level systems.
LodLevel
Level of detail configuration
Material
Material properties for rendering
Plane
Plane equation ax + by + cz + d = 0
RenderData
Rendering data for a scene node
Scene
Scene graph managing hierarchical plot objects
SceneNode
Scene node representing a renderable object
SceneStatistics
Scene statistics for debugging and optimization

Enums

AlphaMode
Alpha blending mode
ImageData
CPU-side image payload for textured rendering

Type Aliases

NodeId
Unique identifier for scene nodes