render_interactive_with_handle

Function render_interactive_with_handle 

pub fn render_interactive_with_handle(
    handle: u32,
    figure: Figure,
) -> Result<String, String>
Show an interactive plot that is tied to a specific MATLAB figure handle. This allows embedding runtimes to request that a window close when the corresponding figure lifecycle event fires.