Module bar

Module bar 

Structs

BarGpuInputs
Inputs required to pack bar vertices directly on the GPU.
BarGpuParams
Parameters describing how the GPU vertices should be generated.

Enums

BarLayoutMode
BarOrientation

Functions

pack_vertices_from_values
Builds a GPU-resident vertex buffer for bar charts directly from provider-owned value arrays.