Module surface

Module surface 

Structs

SurfaceGpuInputs
Inputs required to pack surface vertices directly on the GPU.
SurfaceGpuParams
Parameters describing how the GPU vertices should be generated.

Functions

pack_surface_vertices
Builds a GPU-resident vertex buffer for surface plots directly from provider-owned Z data.

Type Aliases

SurfaceAxis
Axis data source used by the GPU surface vertex packer.