Module tuning

Module tuning 

Functions

effective_workgroup_size
Returns the currently configured workgroup size for plot compute shaders.
set_effective_workgroup_size
Update the workgroup size hint using the acceleration provider’s auto-calibrated value. Values of zero are ignored to avoid disabling the fallback default.