register_handle

Function register_handle 

pub fn register_handle(handle: u32) -> Result<WindowRegistration, String>
Render a figure in an interactive window that is tied to a specific MATLAB figure handle.

When the runtime later emits a FigureEventKind::Closed for the same handle, calling request_close will trigger the associated window to shut down.