pub fn render_interactive_with_handle(
handle: u32,
figure: Figure,
) -> Result<String, String>Expand description
Show an interactive plot that is tied to a specific MATLAB figure handle. This allows embedding runtimes to request that a window close when the corresponding figure lifecycle event fires.