Structs
- Surface
GpuInputs - Inputs required to pack surface vertices directly on the GPU.
- Surface
GpuParams - Parameters describing how the GPU vertices should be generated.
Functions
- pack_
surface_ vertices - Builds a GPU-resident vertex buffer for surface plots directly from provider-owned Z data.
Type Aliases
- Surface
Axis - Axis data source used by the GPU surface vertex packer.