pub fn set_effective_workgroup_size(value: u32)
Update the workgroup size hint using the acceleration provider’s auto-calibrated value. Values of zero are ignored to avoid disabling the fallback default.