Single Window Manager - V8-caliber EventLoop management
Ensures only one interactive plot window exists at a time, avoiding winit’s “EventLoop can’t be recreated” error.
Functions
- is_
window_ available - Check if the window system is available
- show_
plot_ sequential - Show a plot using a single, managed window approach
- show_
plot_ sequential_ with_ signal - Same as
show_plot_sequential, but allows callers to provide a close signal that can terminate the window externally (e.g. from a figure lifecycle event).